<?php

/* $Id: persian-windows-1256.inc.php,v 2.96 2005/10/30 10:03:50 nijel Exp $ */
/*
Persian(Farsi) translation by : Bornis Group
www.BornisGroup.com
info@BornisGroup.com
*/
$charset = 'windows-1256';
$text_dir = 'rtl'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'Tahoma, verdana, arial, helvetica, sans-serif';
$right_font_family = '"Windows UI", Tahoma, verdana, arial, helvetica, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('', '', ' ', ' ', '', ' ', 'ǐ ');

$day_of_week = array('', '', '', '', '̝', '', '');
$month = array('', '', '', '', '', '', '', '', 'Ӂ', '', '', '');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y  %I:%M %p';
$timespanfmt = '%s days, %s hours, %s minutes and %s seconds'; //to translate

$strAccessDenied = '  ';
$strAction = '';
$strAddDeleteColumn = '   ';
$strAddDeleteRow = '/ ';
$strAddNewField = '  ';
$strAddSearchConditions = '   (  "where"):';
$strAddUserMessage = '     .';
$strAddUser = '   ';
$strAffectedRows = '   ڝ:';
$strAfterInsertBack = '   ';
$strAfterInsertNewInsert = '    ';
$strAfter = '  %s';
$strAllTableSameWidth = '     ';
$strAll = '';
$strAlterOrderBy = '    ';
$strAnalyzeTable = ' ';
$strAnd = '';
$strAnIndex = '   %s  .';
$strAnyHost = ' ';
$strAnyUser = ' ';
$strAny = '';
$strAPrimaryKey = '    %s  ';
$strAscending = '';
$strAtBeginningOfTable = '  ';
$strAtEndOfTable = '  ';
$strAttr = '펐';

$strBack = 'Ґ';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = '';
$strBrowse = '';
$strBzip = '"bzipped"';

$strCantLoadRecodeIconv = 'ѐ iconv   recode extension          ϡ php              (charset conversion)   phpMyAdmin  .';
$strCantRenameIdxToPrimary = '   PRIMARY  !';
$strChangeDisplay = '     ';
$strChangePassword = '  ';
$strChange = '';
$strCharsetOfFile = '  :';
$strCheckAll = ' ';
$strCheckTable = ' ';
$strChoosePage = '       ';
$strColComFeat = '  ';
$strColumnNames = ' ';
$strComments = '';
$strCompleteInserts = ' ';
$strCompression = '';
$strConfigFileError = 'phpMyAdmin      !<br />              php .<br />           ()  php     .        (" \' ")  ѐ (" ; ")    .<br />ǐ          .';
$strConfigureTableCoord = '   %s   ';
$strCopyTableOK = ' %s  %s ߁ .';
$strCopyTable = '߁    ( <b>.</b>):';
$strCreateIndexTopic = '  ';
$strCreateIndex = '   &nbsp;%s&nbsp;';
$strCreateNewDatabase = '   ';
$strCreateNewTable = '      %s';
$strCreatePage = '   ';
$strCreatePdfFeat = ' PDFs';
$strCreate = '';
$strCriteria = '';

$strDatabaseHasBeenDropped = '  %s  .';
$strDatabasesStats = '  ';
$strDatabases = ' ';
$strDatabase = ' ';
$strDataDict = ' ';
$strDataOnly = ' ';
$strData = '';
$strDefault = 'ԝ';
$strDeletedRows = ' ݝ :';
$strDeleted = '   .';
$strDelete = '';
$strDescending = '';
$strDisabled = '';
$strDisplayFeat = ' ';
$strDisplayOrder = ' :';
$strDisplayPDF = '  PDF';
$strDoAQuery = '  "    " (wildcard: "%")';
$strDocu = '';
$strDoYouReally = '   ';
$strDrop = '';
$strDumpingData = '  ';
$strDumpXRows = ' %s ()     %s.';
$strDynamic = '';

$strEditPDFPages = '  PDF';
$strEditPrivileges = ' ';
$strEdit = '';
$strEffective = '';
$strEmptyResultSet = 'MySQL    . ( 0 ).';
$strEmpty = ' ';
$strEnabled = '';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEnd = '';
$strEnglishPrivileges = '  :   MySQL      .';
$strError = '';
$strExplain = '  SQL';
$strExport = '';
$strExtendedInserts = ' ';
$strExtra = '';

$strFieldHasBeenDropped = ' %s  ';
$strFieldsEmpty = '    ! ';
$strFieldsEnclosedBy = ' 䝐 ';
$strFieldsEscapedBy = '  ';
$strFieldsTerminatedBy = '  ';
$strFields = '';
$strField = '';
$strFixed = 'fixed';
$strFlushTable = 'Flush the table ("FLUSH")';
$strFormat = '';
$strFormEmpty = '     !';
$strFullText = ' ';
$strFunction = '';

$strGenBy = 'ϝ ';
$strGenTime = ' ';
$strGo = '';
$strGzip = '"gzipped"';

$strHasBeenAltered = ' .';
$strHasBeenCreated = ' .';
$strHaveToShow = '         ';
$strHomepageOfficial = '   phpMyAdmin';
$strHome = '';
$strHostEmpty = '   !';
$strHost = '';

$strIdxFulltext = ' ';
$strIgnore = 'Ignore';
$strImportDocSQL = '   docSQL';
$strIndexes = 'ʝ';
$strIndexHasBeenDropped = ' %s  ';
$strIndexName = ' &nbsp;:';
$strIndexType = ' &nbsp;:';
$strIndex = '';
$strInsecureMySQL = '      ( root   )     ԝ MySQL .  MySQL   ԝ              .';
$strInsertAsNewRow = '     ';
$strInsertedRows = ' ̝:';
$strInsertNewRow = '  ';
$strInsert = '';
$strInUse = 'in use';

$strKeepPass = '   ';
$strKeyname = 'Keyname';
$strKill = 'Kill';

$strLengthSet = '/*';
$strLimitNumRows = '    ';
$strLinesTerminatedBy = '  ';
$strLinkNotFound = '  ';
$strLinksTo = ' ';
$strLocationTextfile = '  ';
$strLogin = '';
$strLogout = '';
$strLogPassword = ' :';
$strLogUsername = ' :';

$strModifications = '  ';
$strModifyIndexTopic = '  ';
$strModify = '';
$strMoveTableOK = ' %s  %s  .';
$strMoveTable = '   ( <b>.</b>):';
$strMySQLCharset = '  MySQL';
$strMySQLReloaded = 'MySQL  ѐ .';
$strMySQLSaid = ' MySQL :';
$strMySQLServerProcess = 'MySQL %pma_s1%    %pma_s2%  %pma_s3%';
$strMySQLShowProcess = ' ';
$strMySQLShowStatus = '  MySQL';
$strMySQLShowVars = '   MySQL';

$strName = '';
$strNext = '';
$strNoDatabases = 'No databases';
$strNoDescription = 'no Description';
$strNoDropDatabases = ' "DROP DATABASE"  .';
$strNoIndex = '  ݝ!';
$strNone = '';
$strNoPassword = '  ';
$strNoPhp = '  PHP';
$strNoTablesFound = '        .';
$strNotNumber = '   !';
$strNotOK = 'not OK';
$strNotSet = ' <b>%s</b>      %s  ';
$strNoUsersFound = '   .';
$strNo = '';
$strNull = '';
$strNumTables = '';

$strOK = '';
$strOperations = '';
$strOptimizeTable = ' ';
$strOr = '';

$strPageNumber = ' :';
$strPasswordEmpty = '   !';
$strPasswordNotSame = '    !';
$strPassword = ' ';
$strPdfInvalidTblName = ' "%s"  !';
$strPdfNoTables = 'No tables';
$strPersian = '';
$strPHPVersion = ' PHP';
$strPhp = '  PHP';
$strPmaDocumentation = ' phpMyAdmin';
$strPos1 = '';
$strPrevious = '';
$strPrimaryKeyHasBeenDropped = '   ';
$strPrimaryKeyName = '    PRIMARY  !';
$strPrimaryKeyWarning = '(<b>   </b> "PRIMARY"     !)';
$strPrimary = '';
$strPrintView = ' ǁ';
$strPrint = 'ǁ';
$strPrivileges = '';
$strPutColNames = '     ';

$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQBE = '  ';
$strQueryOnDb = '   SQL    <b>%s</b>:';

$strRecords = '';
$strRelationNotWorking ='         .     %s%s   .';
$strReloadMySQL = '   MySQL';
$strRenameTableOK = ' %s  %s   ';
$strRenameTable = '  ';
$strRepairTable = ' ';
$strReplaceTable = '    ';
$strReset = 'Reset';
$strReType = '';
$strRevokeMessage = '  %s   ';
$strRevoke = '';
$strRowLength = ' ';
$strRowsFrom = '()     ';
$strRowSize = '   ';
$strRowsModeHorizontal = '';
$strRowsModeVertical = '';
$strRowsStatistic = ' ';
$strRows = '';
$strRunning = '  %s';
$strRunQuery = 'Submit Query';
$strRunSQLQuery = '   () SQL   %s';

$strSave = '';
$strSearchFormTitle = '  ';
$strSearchInTables = ' () :';
$strSearchNeedle = '()  ()   (wildcard: "%"):';
$strSearchOption1 = '   ';
$strSearchOption2 = ' ';
$strSearchOption3 = ' ';
$strSearchOption4 = '  (as regular expression)';
$strSearchResultsFor = '  "<i>%s</i>" %s:';
$strSearchType = '  :';
$strSearch = '';
$strSelectADb = '      .';
$strSelectAll = ' ';
$strSelectFields = '    ( )';
$strSelectNumRows = 'in query';
$strSelectTables = 'Select Tables';
$strSend = '   ';
$strServerVersion = ' ';
$strServer = '';
$strSetEnumVal = 'ǐ   "enum"  "set"            : \'a\',\'b\',\'c\'...<br /> ǐ       (ߝ) (" \ ")    (" \' ")           (" \ ")  Ȑ<br /> ( \'\\\\xyz\'  \'a\\\'b\')';
$strShowAll = ' ';
$strShowColor = ' ';
$strShowGrid = 'Show grid';
$strShowingRecords = 'Showing rows';
$strShowPHPInfo = '  PHP';
$strShowTableDimension = '  ';
$strShowTables = ' ';
$strShowThisQuery = '         ';
$strShow = '';
$strSingly = '()';
$strSize = '';
$strSort = '';
$strSpaceUsage = ' ';
$strSplitWordsWithSpace = '    (" ")  .';
$strSQLQuery = '   SQL';
$strSQLResult = ' SQL';
$strSQL = 'SQL';
$strStatement = '';
$strStrucCSV = ' CSV';
$strStrucData = '  ';
$strStrucDrop = ' \' ݝ\'';
$strStrucExcelCSV = 'CSV   MS Excel';
$strStrucOnly = ' ';
$strStructPropose = '  ';
$strStructure = '';
$strSubmit = '';
$strSuccess = '   SQL     ';
$strSum = '';

$strTableComments = ' ';
$strTableEmpty = '    !';
$strTableHasBeenDropped = ' %s  ';
$strTableHasBeenEmptied = ' %s  ';
$strTableMaintenance = ' ';
$strTables = '%s ()';
$strTableType = ' ';
$strTable = '';
$strTotalUC = ' ';
$strTotal = ' ';
$strType = '';

$strUncheckAll = '  ';
$strUnique = '';
$strUnselectAll = '  ';
$strUpdatePrivMessage = ' %s   .';
$strUpdateProfileMessage = '   .';
$strUpdateQuery = '    ';
$strUsage = '';
$strUseBackquotes = '        (" \' ")';
$strUserEmpty = '   !';
$strUserName = ' ';
$strUser = '';
$strUseTables = 'ѐ ';

$strValidateSQL = ' SQL';
$strValue = '';
$strViewDumpDB = '   ';
$strViewDump = '  ';

$strWebServerUploadDirectoryError = '          .';
$strWelcome = ' %s ԝ';
$strWithChecked = ' ȝ :';
$strWrongUser = ' /   .   .';

$strYes = '';

$strZip = '"zipped"';

// To translate:
$strAbortedClients = 'Aborted'; //to translate
$strAbsolutePathToDocSqlDir = 'Please enter the absolute path on webserver to docSQL directory'; //to translate
$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.'; //to translate
$strAddAutoIncrement = 'Add AUTO_INCREMENT value'; //to translate
$strAddConstraints = 'Add constraints';  //to translate
$strAddDropDatabase = 'Add DROP DATABASE'; //to translate
$strAddedColumnComment = 'Added comment for column'; //to translate
$strAddedColumnRelation = 'Added relation for column'; //to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strAddIntoComments = 'Add into comments'; //to translate
$strAddPrivilegesOnDb = 'Add privileges on the following database'; //to translate
$strAddPrivilegesOnTbl = 'Add privileges on the following table'; //to translate
$strAddToIndex = 'Add to index &nbsp;%s&nbsp;column(s)'; //to translate
$strAdministration = 'Administration'; //to translate
$strAfterInsertSame = 'Go back to this page';  //to translate
$strArabic = 'Arabic'; //to translate
$strArmenian = 'Armenian'; //to translate
$strAutodetect = 'Autodetect'; //to translate
$strAutomaticLayout = 'Automatic layout'; //to translate

$strBaltic = 'Baltic'; //to translate
$strBinaryDoNotEdit = 'Binary - do not edit'; //to translate
$strBookmarkAllUsers = 'Let every user access this bookmark'; //to translate
$strBookmarkDeleted = 'The bookmark has been deleted.'; //to translate
$strBookmarkLabel = 'Label'; //to translate
$strBookmarkQuery = 'Bookmarked SQL-query'; //to translate
$strBookmarkThis = 'Bookmark this SQL-query'; //to translate
$strBookmarkView = 'View only'; //to translate
$strBrowseForeignValues = 'Browse foreign values'; //to translate
$strBulgarian = 'Bulgarian'; //to translate
$strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz2 extension in this php version. It is strongly recommended to set the <code>$cfg[\'BZipDump\']</code> directive in your phpMyAdmin configuration file to <code>FALSE</code>. If you want to use the Bz2 compression features, you should upgrade to a later php version. See php bug report %s for details.'; //to translate

$strCalendar = 'Calendar';  //to translate
$strCannotLogin = 'Cannot login to MySQL server'; //to translate
$strCantLoad = 'cannot load %s extension,<br />please check PHP Configuration'; //to translate
$strCantUseRecodeIconv = 'Can not use iconv nor libiconv nor recode_string function while extension reports to be loaded. Check your php configuration.'; //to translate
$strCardinality = 'Cardinality'; //to translate
$strCaseInsensitive = 'case-insensitive'; //to translate
$strCaseSensitive = 'case-sensitive'; //to translate
$strCentralEuropean = 'Central European'; //to translate
$strChangeCopyModeCopy = '... keep the old one.'; //to translate
$strChangeCopyMode = 'Create a new user with the same privileges and ...'; //to translate
$strChangeCopyModeDeleteAndReload = ' ... delete the old one from the user tables and reload the privileges afterwards.'; //to translate
$strChangeCopyModeJustDelete = ' ... delete the old one from the user tables.'; //to translate
$strChangeCopyModeRevoke = ' ... revoke all active privileges from the old one and delete it afterwards.'; //to translate
$strChangeCopyUser = 'Change Login Information / Copy User'; //to translate
$strCharset = 'Charset'; //to translate
$strCharsetsAndCollations = 'Character Sets and Collations'; //to translate
$strCharsets = 'Charsets'; //to translate
$strCheckOverhead = 'Check tables with overhead';  //to translate
$strCheckPrivs = 'Check Privileges'; //to translate
$strCheckPrivsLong = 'Check privileges for database &quot;%s&quot;.'; //to translate
$strCollation = 'Collation'; //to translate
$strColumnPrivileges = 'Column-specific privileges'; //to translate
$strCommand = 'Command'; //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strConnections = 'Connections'; //to translate
$strConstraintsForDumped = 'Constraints for dumped tables'; //to translate
$strConstraintsForTable = 'Constraints for table'; //to translate
$strCookiesRequired = 'Cookies must be enabled past this point.'; //to translate
$strCopyTableSameNames = 'Can\'t copy table to same one!'; //to translate
$strCouldNotKill = 'phpMyAdmin was unable to kill thread %s. It probably has already been closed.'; //to translate
$strCreationDates = 'Creation/Update/Check dates';  //to translate
$strCroatian = 'Croatian'; //to translate
$strCSVOptions = 'CSV options'; //to translate
$strCyrillic = 'Cyrillic'; //to translate
$strCzech = 'Czech'; //to translate
$strCzechSlovak = 'Czech-Slovak';  //to translate

$strDanish = 'Danish'; //to translate
$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDatabaseExportOptions = 'Database export options'; //to translate
$strDatabaseNoTable = 'This database contains no table!'; //to translate
$strDatabasesDropped = '%s databases have been dropped successfully.'; //to translate
$strDatabasesStatsDisable = 'Disable Statistics'; //to translate
$strDatabasesStatsEnable = 'Enable Statistics'; //to translate
$strDatabasesStatsHeavyTraffic = 'Note: Enabling the Database statistics here might cause heavy traffic between the webserver and the MySQL one.'; //to translate
$strDBComment = 'Database comment: '; //to translate
$strDBGContext = 'Context'; //to translate
$strDBGContextID = 'Context ID'; //to translate
$strDBGHits = 'Hits'; //to translate
$strDBGLine = 'Line'; //to translate
$strDBGMaxTimeMs = 'Max time, ms'; //to translate
$strDBGMinTimeMs = 'Min time, ms'; //to translate
$strDBGModule = 'Module'; //to translate
$strDBGTimePerHitMs = 'Time/Hit, ms'; //to translate
$strDBGTotalTimeMs = 'Total time, ms'; //to translate
$strDbPrivileges = 'Database-specific privileges'; //to translate
$strDBRename = 'Rename database to';  //to translate
$strDbSpecific = 'database-specific'; //to translate
$strDefaultValueHelp = 'For default values, please enter just a single value, without backslash escaping or quotes, using this format: a'; //to translate
$strDefragment = 'Defragment table';  //to translate
$strDelayedInserts = 'Use delayed inserts';  //to translate
$strDeleteAndFlush = 'Delete the users and reload the privileges afterwards.'; //to translate
$strDeleteAndFlushDescr = 'This is the cleanest way, but reloading the privileges may take a while.'; //to translate
$strDeleting = 'Deleting %s'; //to translate
$strDelOld = 'The current Page has References to Tables that no longer exist. Would you like to delete those References?'; //to translate
$strDescription = 'Description'; //to translate
$strDictionary = 'dictionary'; //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strDropSelectedDatabases = 'Drop Selected Databases'; //to translate
$strDropUsersDb = 'Drop the databases that have the same names as the users.'; //to translate
$strDumpSaved = 'Dump has been saved to file %s.'; //to translate

$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strEnglish = 'English'; //to translate
$strEstonian = 'Estonian'; //to translate
$strExcelEdition = 'Excel edition';  //to translate
$strExcelOptions = 'Excel options'; //to translate
$strExecuteBookmarked = 'Execute bookmarked query'; //to translate

$strFailedAttempts = 'Failed attempts'; //to translate
$strFileAlreadyExists = 'File %s already exists on server, change filename or check overwrite option.'; //to translate
$strFileCouldNotBeRead = 'File could not be read'; //to translate
$strFileNameTemplate = 'File name template'; //to translate
$strFileNameTemplateHelp = 'Use __DB__ for database name, __TABLE__ for table name and %sany strftime%s options for time specification, extension will be automagically added. Any other text will be preserved.'; //to translate
$strFileNameTemplateRemember = 'remember template'; //to translate
$strFlushPrivilegesNote = 'Note: phpMyAdmin gets the users\' privileges directly from MySQL\'s privilege tables. The content of these tables may differ from the privileges the server uses if manual changes have made to it. In this case, you should %sreload the privileges%s before you continue.'; //to translate

$strGeneralRelationFeat = 'General relation features'; //to translate
$strGeorgian = 'Georgian';  //to translate
$strGerman = 'German'; //to translate
$strGlobal = 'global'; //to translate
$strGlobalPrivileges = 'Global privileges'; //to translate
$strGlobalValue = 'Global value'; //to translate
$strGrantOption = 'Grant'; //to translate
$strGreek = 'Greek'; //to translate

$strHebrew = 'Hebrew'; //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strHungarian = 'Hungarian'; //to translate

$strIcelandic = 'Icelandic';  //to translate
$strId = 'ID'; //to translate
$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strIgnoringFile = 'Ignoring file %s'; //to translate
$strImportFiles = 'Import files'; //to translate
$strImportFinished = 'Import finished'; //to translate
$strInnodbStat = 'InnoDB Status'; //to translate
$strInsertedRowId = 'Inserted row id:'; //to translate
$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.'; //to translate
$strInternalRelations = 'Internal relations'; //to translate

$strJapanese = 'Japanese'; //to translate
$strJumpToDB = 'Jump to database &quot;%s&quot;.'; //to translate
$strJustDeleteDescr = 'The &quot;deleted&quot; users will still be able to access the server as usual until the privileges are reloaded.'; //to translate
$strJustDelete = 'Just delete the users from the privilege tables.'; //to translate

$strKorean = 'Korean'; //to translate

$strLandscape = 'Landscape'; //to translate
$strLatexCaption = 'Table caption'; //to translate
$strLatexContent = 'Content of table __TABLE__'; //to translate
$strLatexContinuedCaption = 'Continued table caption'; //to translate
$strLatexContinued = '(continued)'; //to translate
$strLatexIncludeCaption = 'Include table caption'; //to translate
$strLatexLabel = 'Label key'; //to translate
$strLaTeX = 'LaTeX'; //to translate
$strLaTeXOptions = 'LaTeX options'; //to translate
$strLatexStructure = 'Structure of table __TABLE__'; //to translate
$strLatvian = 'Latvian';  //to translate
$strLithuanian = 'Lithuanian'; //to translate
$strLocalhost = 'Local'; //to translate
$strLoginInformation = 'Login Information'; //to translate
$strLogServer = 'Server'; //to translate

$strMaximumSize = 'Maximum size: %s%s';  //to translate
$strMIME_available_mime = 'Available MIME-types'; //to translate
$strMIME_available_transform = 'Available transformations'; //to translate
$strMIME_description = 'Description'; //to translate
$strMIME_MIMEtype = 'MIME-type'; //to translate
$strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.'; //to translate
$strMIME_transformation = 'Browser transformation'; //to translate
$strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s'; //to translate
$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').'; //to translate
$strMIME_transformation_options = 'Transformation options'; //to translate
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function'; //to translate
$strMoveTableSameNames = 'Can\'t move table to same one!'; //to translate
$strMultilingual = 'multilingual'; //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate

$strNoDatabasesSelected = 'No databases selected.'; //to translate
$strNoExplain = 'Skip Explain SQL'; //to translate
$strNoFrames = 'phpMyAdmin is more friendly with a <b>frames-capable</b> browser.'; //to translate
$strNoIndexPartsDefined = 'No index parts defined!'; //to translate
$strNoModification = 'No change'; //to translate
$strNoOptions = 'This format has no options'; //to translate
$strNoPermission = 'The web server does not have permission to save the file %s.'; //to translate
$strNoPrivileges = 'No Privileges'; //to translate
$strNoRights = 'You don\'t have enough rights to be here right now!'; //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strNoSpace = 'Insufficient space to save the file %s.'; //to translate
$strNoValidateSQL = 'Skip Validate SQL'; //to translate
$strNumSearchResultsInTable = '%s match(es) inside table <i>%s</i>'; //to translate
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> match(es)'; //to translate

$strOperator = 'Operator';  //to translate
$strOverhead = 'Overhead'; //to translate
$strOverwriteExisting = 'Overwrite existing file(s)'; //to translate

$strPaperSize = 'Paper size'; //to translate
$strPartialText = 'Partial Texts'; //to translate
$strPasswordChanged = 'The Password for %s was changed successfully.'; //to translate
$strPdfDbSchema = 'Schema of the the "%s" database - Page %s'; //to translate
$strPerHour = 'per hour'; //to translate
$strPerMinute = 'per minute'; //to translate
$strPerSecond = 'per second'; //to translate
$strPhoneBook = 'phone book'; //to translate
$strPHP40203 = 'You are using PHP 4.2.3, which has a serious bug with multi-byte strings (mbstring). See PHP bug report 19404. This version of PHP is not recommended for use with phpMyAdmin.'; //to translate
$strPmaUriError = 'The <tt>$cfg[\'PmaAbsoluteUri\']</tt> directive MUST be set in your configuration file!'; //to translate
$strPolish = 'Polish';  //to translate
$strPortrait = 'Portrait'; //to translate
$strPrintViewFull = 'Print view (with full texts)'; //to translate
$strPrivDescAllPrivileges = 'Includes all privileges except GRANT.'; //to translate
$strPrivDescAlter = 'Allows altering the structure of existing tables.'; //to translate
$strPrivDescCreateDb = 'Allows creating new databases and tables.'; //to translate
$strPrivDescCreateTbl = 'Allows creating new tables.'; //to translate
$strPrivDescCreateTmpTable = 'Allows creating temporary tables.'; //to translate
$strPrivDescDelete = 'Allows deleting data.'; //to translate
$strPrivDescDropDb = 'Allows dropping databases and tables.'; //to translate
$strPrivDescDropTbl = 'Allows dropping tables.'; //to translate
$strPrivDescExecute = 'Allows running stored procedures; Has no effect in this MySQL version.'; //to translate
$strPrivDescFile = 'Allows importing data from and exporting data into files.'; //to translate
$strPrivDescGrant = 'Allows adding users and privileges without reloading the privilege tables.'; //to translate
$strPrivDescIndex = 'Allows creating and dropping indexes.'; //to translate
$strPrivDescInsert = 'Allows inserting and replacing data.'; //to translate
$strPrivDescLockTables = 'Allows locking tables for the current thread.'; //to translate
$strPrivDescMaxConnections = 'Limits the number of new connections the user may open per hour.'; //to translate
$strPrivDescMaxQuestions = 'Limits the number of queries the user may send to the server per hour.'; //to translate
$strPrivDescMaxUpdates = 'Limits the number of commands that change any table or database the user may execute per hour.'; //to translate
$strPrivDescProcess3 = 'Allows killing processes of other users.'; //to translate
$strPrivDescProcess4 = 'Allows viewing the complete queries in the process list.'; //to translate
$strPrivDescReferences = 'Has no effect in this MySQL version.'; //to translate
$strPrivDescReload = 'Allows reloading server settings and flushing the server\'s caches.'; //to translate
$strPrivDescReplClient = 'Gives the right to the user to ask where the slaves / masters are.'; //to translate
$strPrivDescReplSlave = 'Needed for the replication slaves.'; //to translate
$strPrivDescSelect = 'Allows reading data.'; //to translate
$strPrivDescShowDb = 'Gives access to the complete list of databases.'; //to translate
$strPrivDescShutdown = 'Allows shutting down the server.'; //to translate
$strPrivDescSuper = 'Allows connecting, even if maximum number of connections is reached; Required for most administrative operations like setting global variables or killing threads of other users.'; //to translate
$strPrivDescUpdate = 'Allows changing data.'; //to translate
$strPrivDescUsage = 'No privileges.'; //to translate
$strPrivilegesReloaded = 'The privileges were reloaded successfully.'; //to translate
$strProcesslist = 'Process list'; //to translate

$strQueryFrame = 'Query window'; //to translate
$strQuerySQLHistory = 'SQL-history'; //to translate
$strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.'; //to translate
$strQueryTime = 'Query took %01.4f sec'; //to translate
$strQueryType = 'Query type'; //to translate
$strQueryWindowLock = 'Do not overwrite this query from outside the window'; //to translate

$strReceived = 'Received'; //to translate
$strReferentialIntegrity = 'Check referential integrity:'; //to translate
$strRefresh = 'Refresh';  //to translate
$strRelationalSchema = 'Relational schema'; //to translate
$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strRelations = 'Relations'; //to translate
$strRelationView = 'Relation view'; //to translate
$strReloadFailed = 'MySQL reload failed.'; //to translate
$strReloadingThePrivileges = 'Reloading the privileges'; //to translate
$strRemoveSelectedUsers = 'Remove selected users'; //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
$strReplaceNULLBy = 'Replace NULL by'; //to translate
$strResourceLimits = 'Resource limits'; //to translate
$strRevokeAndDeleteDescr = 'The users will still have the USAGE privilege until the privileges are reloaded.'; //to translate
$strRevokeAndDelete = 'Revoke all active privileges from the users and delete them afterwards.'; //to translate
$strRomanian = 'Romanian';  //to translate
$strRowsModeFlippedHorizontal = 'horizontal (rotated headers)'; //to translate
$strRowsModeOptions = 'in %s mode and repeat headers after %s cells'; //to translate
$strRussian = 'Russian'; //to translate

$strSaveOnServer = 'Save on server in %s directory'; //to translate
$strScaleFactorSmall = 'The scale factor is too small to fit the schema on one page'; //to translate
$strSecretRequired = 'The configuration file now needs a secret passphrase (blowfish_secret).'; //to translate
$strSent = 'Sent'; //to translate
$strServerChoice = 'Server Choice'; //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strServerStatus = 'Runtime Information'; //to translate
$strServerStatusUptime = 'This MySQL server has been running for %s. It started up on %s.'; //to translate
$strServerTabProcesslist = 'Processes'; //to translate
$strServerTabVariables = 'Variables'; //to translate
$strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.'; //to translate
$strServerVars = 'Server variables and settings'; //to translate
$strSessionValue = 'Session value'; //to translate
$strShowDatadictAs = 'Data Dictionary Format'; //to translate
$strShowFullQueries = 'Show Full Queries'; //to translate
$strSimplifiedChinese = 'Simplified Chinese'; //to translate
$strSlovak = 'Slovak';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strSortByKey = 'Sort by key'; //to translate
$strSpanish = 'Spanish';  //to translate
$strSQLExportType = 'Export type';  //to translate
$strSQLOptions = 'SQL options'; //to translate
$strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:'; //to translate
$strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem'; //to translate
$strSQPBugInvalidIdentifer = 'Invalid Identifer'; //to translate
$strSQPBugUnclosedQuote = 'Unclosed quote'; //to translate
$strSQPBugUnknownPunctuation = 'Unknown Punctuation String'; //to translate
$strStatCheckTime = 'Last check'; //to translate
$strStatCreateTime = 'Creation'; //to translate
$strStatUpdateTime = 'Last update'; //to translate
$strStatus = 'Status'; //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strSwedish = 'Swedish'; //to translate
$strSwitchToTable = 'Switch to copied table'; //to translate

$strTableHasBeenFlushed = 'Table %s has been flushed'; //to translate
$strTableOfContents = 'Table of contents'; //to translate
$strTableOptions = 'Table options'; //to translate
$strTableStructure = 'Table structure for table'; //to translate
$strTakeIt = 'take it';  //to translate
$strTblPrivileges = 'Table-specific privileges'; //to translate
$strTextAreaLength = ' Because of its length,<br /> this field might not be editable '; //to translate
$strThai = 'Thai'; //to translate
$strTheme = 'Theme / Style';  //to translate
$strThisHost = 'This Host'; //to translate
$strThisNotDirectory = 'This was not a directory'; //to translate
$strThreadSuccessfullyKilled = 'Thread %s was successfully killed.'; //to translate
$strTime = 'Time'; //to translate
$strToggleScratchboard = 'Toggle scratchboard'; //to translate
$strTraditionalChinese = 'Traditional Chinese'; //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strTraffic = 'Traffic'; //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)'; //to translate
$strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).'; //to translate
$strTransformation_image_png__inline = 'See image/jpeg: inline'; //to translate
$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().'; //to translate
$strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)'; //to translate
$strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.'; //to translate
$strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.'; //to translate
$strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.'; //to translate
$strTransformation_text_plain__substr = 'Only shows part of a string. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .'; //to translate
$strTruncateQueries = 'Truncate Shown Queries'; //to translate
$strTurkish = 'Turkish'; //to translate

$strUkrainian = 'Ukrainian'; //to translate
$strUnicode = 'Unicode'; //to translate
$strUnknown = 'unknown'; //to translate
$strUpdComTab = 'Please see Documentation on how to update your Column_comments Table'; //to translate
$strUpgrade = 'You should upgrade to %s %s or later.'; //to translate
$strUseHostTable = 'Use Host Table'; //to translate
$strUserAlreadyExists = 'The user %s already exists!'; //to translate
$strUserNotFound = 'The selected user was not found in the privilege table.'; //to translate
$strUserOverview = 'User overview'; //to translate
$strUsersDeleted = 'The selected users have been deleted successfully.'; //to translate
$strUsersHavingAccessToDb = 'Users having access to &quot;%s&quot;'; //to translate
$strUseTextField = 'Use text field'; //to translate
$strUseThisValue = 'Use this value'; //to translate

$strValidatorError = 'The SQL validator could not be initialized. Please check if you have installed the necessary php extensions as described in the %sdocumentation%s.'; //to translate
$strVar = 'Variable'; //to translate
$strViewDumpDatabases = 'View dump (schema) of databases'; //to translate

$strWebServerUploadDirectory = 'web-server upload directory'; //to translate
$strWestEuropean = 'West European'; //to translate
$strWildcard = 'wildcard'; //to translate
$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings'; //to translate
$strWritingCommentNotPossible = 'Writing of comment not possible'; //to translate
$strWritingRelationNotPossible = 'Writing of relation not possible'; //to translate

$strXML = 'XML'; //to translate

$strZeroRemovesTheLimit = 'Note: Setting these options to 0 (zero) removes the limit.'; //to translate

$strAddFields = 'Add %s field(s)';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
$strCSV = 'CSV';  //to translate
$strImport = 'Import';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strFileToImport = 'File to import';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate
$strPartialImport = 'Partial import';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate
$strHandler = 'Handler';  //to translate
$strJoins = 'Joins';  //to translate
$strKeyCache = 'Key cache';  //to translate
$strMaxConnects = 'max. concurrent connections';  //to translate
$strQueryCache = 'Query cache';  //to translate
$strReplication = 'Replication';  //to translate
$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSorting = 'Sorting';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThreads = 'Threads';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
$strEsperanto = 'Esperanto';  //to translate
?>
